@@ -20,13 +20,15 @@ objects that implement the reduce protocol::
 
 """
 
-import base64
 import sys
 import datetime
 import time
 import collections
 
+from jsonpickle import util
 from jsonpickle.compat import unicode
+from jsonpickle.compat import bytes
+from jsonpickle.compat import PY3
 
 
 class Registry(object):
@@ -90,19 +92,21 @@ class DatetimeHandler(BaseHandler):
             return unicode(obj)
         cls, args = obj.__reduce__()
         flatten = pickler.flatten
-        args = [base64.b64encode(args[0])] + [flatten(i, reset=False) for i in args[1:]]
+        payload = util.b64encode(args[0])
+        args = [payload] + [flatten(i, reset=False) for i in args[1:]]
         data['__reduce__'] = (flatten(cls, reset=False), args)
         return data
 
     def restore(self, obj):
         cls, args = obj['__reduce__']
-        value = base64.b64decode(args[0])
         unpickler = self.context
         restore = unpickler.restore
         cls = restore(cls, reset=False)
+        value = util.b64decode(args[0])
         params = (value,) + tuple([restore(i, reset=False) for i in args[1:]])
         return cls.__new__(cls, *params)
 
+
 register(datetime.datetime, DatetimeHandler)
 register(datetime.date, DatetimeHandler)
 register(datetime.time, DatetimeHandler)
