@@ -1,7 +1,7 @@
 import unittest
 import jsonpickle
 
-from samples import Document, Section, Question
+from jsonpickle._samples import Document, Section, Question
 
 class DocumentTestCase(unittest.TestCase):
     def test_cyclical(self):
@@ -33,7 +33,7 @@ class DocumentTestCase(unittest.TestCase):
         pickled = jsonpickle.encode(document)
         unpickled = jsonpickle.decode(pickled)
 
-        self.assertTrue(str(document) == str(unpickled))
+        self.assertEqual(str(document), str(unpickled))
 
 
 def suite():
