@@ -12,8 +12,10 @@ import time
 
 import jsonpickle.util
 from jsonpickle.compat import unicode
+from jsonpickle.compat import long
 from jsonpickle.util import is_dictionary
 from jsonpickle.util import is_dictionary_subclass
+from jsonpickle.util import is_function
 from jsonpickle.util import is_list
 from jsonpickle.util import is_noncomplex
 from jsonpickle.util import is_primitive
@@ -24,130 +26,139 @@ from jsonpickle.util import is_tuple
 from jsonpickle._samples import Thing, ListSubclass, DictSubclass
 
 
-class PrimitiveTestCase(unittest.TestCase):
+class UtilTestCase(unittest.TestCase):
 
-    def test_int(self):
+    def test_is_primitive_int(self):
         self.assertTrue(is_primitive(0))
         self.assertTrue(is_primitive(3))
         self.assertTrue(is_primitive(-3))
 
-    def test_float(self):
+    def test_is_primitive_float(self):
         self.assertTrue(is_primitive(0))
         self.assertTrue(is_primitive(3.5))
         self.assertTrue(is_primitive(-3.5))
         self.assertTrue(is_primitive(float(3)))
 
-    def test_long(self):
+    def test_is_primitive_long(self):
         self.assertTrue(is_primitive(long(3)))
 
-    def test_bool(self):
+    def test_is_primitive_bool(self):
         self.assertTrue(is_primitive(True))
         self.assertTrue(is_primitive(False))
 
-    def test_None(self):
+    def test_is_primitive_None(self):
         self.assertTrue(is_primitive(None))
 
-    def test_str(self):
+    def test_is_primitive_str(self):
         self.assertTrue(is_primitive('hello'))
         self.assertTrue(is_primitive(''))
 
-    def test_unicode(self):
+    def test_is_primitive_unicode(self):
         self.assertTrue(is_primitive(unicode('hello')))
         self.assertTrue(is_primitive(unicode('')))
         self.assertTrue(is_primitive(unicode('hello')))
 
-    def test_list(self):
+    def test_is_primitive_list(self):
         self.assertFalse(is_primitive([]))
         self.assertFalse(is_primitive([4, 4]))
 
-    def test_dict(self):
+    def test_is_primitive_dict(self):
         self.assertFalse(is_primitive({'key':'value'}))
         self.assertFalse(is_primitive({}))
 
-    def test_tuple(self):
+    def test_is_primitive_tuple(self):
         self.assertFalse(is_primitive((1, 3)))
         self.assertFalse(is_primitive((1,)))
 
-    def test_set(self):
+    def test_is_primitive_set(self):
         self.assertFalse(is_primitive(set([1, 3])))
 
-    def test_object(self):
+    def test_is_primitive_object(self):
         self.assertFalse(is_primitive(Thing('test')))
 
-
-class SequenceTestCase(unittest.TestCase):
-
-    def test_list(self):
+    def test_is_list_list(self):
         self.assertTrue(is_list([1, 2]))
 
-    def test_set(self):
+    def test_is_list_set(self):
         self.assertTrue(is_set(set([1, 2])))
 
-    def test_tuple(self):
+    def test_is_list_tuple(self):
         self.assertTrue(is_tuple((1, 2)))
 
-    def test_dict(self):
+    def test_is_list_dict(self):
         self.assertFalse(is_list({'key':'value'}))
         self.assertFalse(is_set({'key':'value'}))
         self.assertFalse(is_tuple({'key':'value'}))
 
-    def test_other(self):
+    def test_is_list_other(self):
         self.assertFalse(is_list(1))
         self.assertFalse(is_set(1))
         self.assertFalse(is_tuple(1))
 
-    def test_is_sequence(self):
+    def test_is_sequence_various(self):
         self.assertTrue(is_sequence([]))
         self.assertTrue(is_sequence(tuple()))
         self.assertTrue(is_sequence(set()))
 
+    def test_is_dictionary_dict(self):
+        self.assertTrue(is_dictionary({}))
 
-class DictionaryTestCase(unittest.TestCase):
+    def test_is_dicitonary_sequences(self):
+        self.assertFalse(is_dictionary([]))
+        self.assertFalse(is_dictionary(set()))
 
-    def test_dict(self):
-        self.assertTrue(is_dictionary({'key':'value'}))
+    def test_is_dictionary_tuple(self):
+        self.assertFalse(is_dictionary(tuple()))
 
-    def test_list(self):
-        self.assertFalse(is_dictionary([1, 2]))
+    def test_is_dictionary_primitive(self):
+        self.assertFalse(is_dictionary(int()))
+        self.assertFalse(is_dictionary(None))
+        self.assertFalse(is_dictionary(str()))
 
+    def test_is_dictionary_subclass_dict(self):
+        self.assertFalse(is_dictionary_subclass({}))
 
-class DictionarySubclassTestCase(unittest.TestCase):
-
-    def test_subclass(self):
+    def test_is_dictionary_subclass_subclass(self):
         self.assertTrue(is_dictionary_subclass(DictSubclass()))
 
-    def test_dict(self):
-        self.assertFalse(is_dictionary_subclass({'key':'value'}))
-
-
-class SequenceSubclassTestCase(unittest.TestCase):
-
-    def test_subclass(self):
+    def test_is_sequence_subclass_subclass(self):
         self.assertTrue(is_sequence_subclass(ListSubclass()))
 
-    def test_list(self):
+    def test_is_sequence_subclass_list(self):
         self.assertFalse(is_sequence_subclass([]))
 
+    def test_is_noncomplex_time_struct(self):
+        t = time.struct_time('123456789')
+        self.assertTrue(is_noncomplex(t))
 
-class NonComplexTestCase(unittest.TestCase):
-    def setUp(self):
-        self.time = time.struct_time('123456789')
-
-    def test_time_struct(self):
-        self.assertTrue(is_noncomplex(self.time))
-
-    def test_other(self):
+    def test_is_noncomplex_other(self):
         self.assertFalse(is_noncomplex('a'))
 
+    def test_is_function_builtins(self):
+        self.assertTrue(is_function(globals))
+
+    def test_is_function_lambda(self):
+        self.assertTrue(is_function(lambda: False))
+
+    def test_is_function_instance_method(self):
+        class Foo(object):
+            def method(self):
+                pass
+            @staticmethod
+            def staticmethod():
+                pass
+            @classmethod
+            def classmethod(cls):
+                pass
+        f = Foo()
+        self.assertTrue(is_function(f.method))
+        self.assertTrue(is_function(f.staticmethod))
+        self.assertTrue(is_function(f.classmethod))
+
 
 def suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(DictionaryTestCase))
-    suite.addTest(unittest.makeSuite(DictionarySubclassTestCase))
-    suite.addTest(unittest.makeSuite(NonComplexTestCase))
-    suite.addTest(unittest.makeSuite(PrimitiveTestCase))
-    suite.addTest(unittest.makeSuite(SequenceTestCase))
-    suite.addTest(unittest.makeSuite(SequenceSubclassTestCase))
+    suite.addTest(unittest.makeSuite(UtilTestCase))
     suite.addTest(doctest.DocTestSuite(jsonpickle.util))
     return suite
 
